Documentation
¶
Index ¶
- type BeaconFunc
- type BlobberFunc
- type ChatFunc
- type CredentialFunc
- type Func
- type GroupFunc
- type ListenerFunc
- type MessageFunc
- type OperatorFunc
- type PkiFunc
- type Query
- type TaskFunc
- type TraverseBeacon
- type TraverseBlobber
- type TraverseChat
- type TraverseCredential
- type TraverseFunc
- type TraverseGroup
- type TraverseListener
- type TraverseMessage
- type TraverseOperator
- type TraversePki
- type TraverseTask
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BeaconFunc ¶
The BeaconFunc type is an adapter to allow the use of ordinary function as a Querier.
type BlobberFunc ¶
The BlobberFunc type is an adapter to allow the use of ordinary function as a Querier.
type CredentialFunc ¶
The CredentialFunc type is an adapter to allow the use of ordinary function as a Querier.
type Func ¶
The Func type is an adapter that allows ordinary functions to be used as interceptors. Unlike traversal functions, interceptors are skipped during graph traversals. Note that the implementation of Func is different from the one defined in entgo.io/ent.InterceptFunc.
type GroupFunc ¶
The GroupFunc type is an adapter to allow the use of ordinary function as a Querier.
type ListenerFunc ¶
The ListenerFunc type is an adapter to allow the use of ordinary function as a Querier.
type MessageFunc ¶
The MessageFunc type is an adapter to allow the use of ordinary function as a Querier.
type OperatorFunc ¶
The OperatorFunc type is an adapter to allow the use of ordinary function as a Querier.
type Query ¶
type Query interface {
// Type returns the string representation of the query type.
Type() string
// Limit the number of records to be returned by this query.
Limit(int)
// Offset to start from.
Offset(int)
// Unique configures the query builder to filter duplicate records.
Unique(bool)
// Order specifies how the records should be ordered.
Order(...func(*sql.Selector))
// WhereP appends storage-level predicates to the query builder. Using this method, users
// can use type-assertion to append predicates that do not depend on any generated package.
WhereP(...func(*sql.Selector))
}
The Query interface represents an operation that queries a graph. By using this interface, users can write generic code that manipulates query builders of different types.
type TraverseBeacon ¶
type TraverseBeacon func(context.Context, *ent.BeaconQuery) error
The TraverseBeacon type is an adapter to allow the use of ordinary function as Traverser.
type TraverseBlobber ¶
type TraverseBlobber func(context.Context, *ent.BlobberQuery) error
The TraverseBlobber type is an adapter to allow the use of ordinary function as Traverser.
type TraverseChat ¶
The TraverseChat type is an adapter to allow the use of ordinary function as Traverser.
type TraverseCredential ¶
type TraverseCredential func(context.Context, *ent.CredentialQuery) error
The TraverseCredential type is an adapter to allow the use of ordinary function as Traverser.
type TraverseFunc ¶
The TraverseFunc type is an adapter to allow the use of ordinary function as Traverser. If f is a function with the appropriate signature, TraverseFunc(f) is a Traverser that calls f.
type TraverseGroup ¶
type TraverseGroup func(context.Context, *ent.GroupQuery) error
The TraverseGroup type is an adapter to allow the use of ordinary function as Traverser.
type TraverseListener ¶
type TraverseListener func(context.Context, *ent.ListenerQuery) error
The TraverseListener type is an adapter to allow the use of ordinary function as Traverser.
type TraverseMessage ¶
type TraverseMessage func(context.Context, *ent.MessageQuery) error
The TraverseMessage type is an adapter to allow the use of ordinary function as Traverser.
type TraverseOperator ¶
type TraverseOperator func(context.Context, *ent.OperatorQuery) error
The TraverseOperator type is an adapter to allow the use of ordinary function as Traverser.
type TraversePki ¶
The TraversePki type is an adapter to allow the use of ordinary function as Traverser.
type TraverseTask ¶
The TraverseTask type is an adapter to allow the use of ordinary function as Traverser.